Examples
========

Single impurity Anderson model
------------------------------

The single impurity Anderson model is an important model in condensed matter physics
which explains phenomena like charge transport properties of disordered materials.
In the following example we demonstrate how Cirq can be used to simulate time evolution of the
Anderson model on a gate based quantum computer.

.. literalinclude:: ../../examples/siam_cirq.py
    :language: python

